## 期货主要品种交易周报

接口：fut_weekly_detail

描述：获取期货交易所主要品种每周交易统计信息，数据从2010年3月开始

权限：600积分可调取，单次最大获取4000行数据，积分越高频次越高，5000积分以上正常调取不受限制

数据来源：中国证监会，本数据由Tushare社区成员CE完成规划和采集

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| week | str | N | 周期（每年第几周，e.g. 202001 表示2020第1周） |
| prd | str | N | 期货品种（支持多品种输入，逗号分隔） |
| start_week | str | N | 开始周期 |
| end_week | str | N | 结束周期 |
| exchange | str | N | 交易所（请参考交易所说明） |
| fields | str | N | 提取的字段，e.g. fields='prd,name,vol' |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| exchange | str | Y | 交易所代码 |
| prd | str | Y | 期货品种代码 |
| name | str | Y | 品种名称 |
| vol | int | Y | 成交量（手） |
| vol_yoy | float | Y | 同比增减（%） |
| amount | float | Y | 成交金额（亿元） |
| amout_yoy | float | Y | 同比增减（%） |
| cumvol | int | Y | 年累计成交总量（手） |
| cumvol_yoy | float | Y | 同比增减（%） |
| cumamt | float | Y | 年累计成交金额（亿元） |
| cumamt_yoy | float | Y | 同比增减（%） |
| open_interest | int | Y | 持仓量（手） |
| interest_wow | float | Y | 环比增减（%） |
| mc_close | float | Y | 本周主力合约收盘价 |
| close_wow | float | Y | 环比涨跌（%） |
| week | str | Y | 周期 |
| week_date | str | Y | 周日期 |

接口示例

```python
#获取期货铜每周交易统计信息
df = pro.fut_weekly_detail(prd='CU')

#获取期货铜每周交易统计信息
df = pro.fut_weekly_detail(prd='CU', start_week='202001', end_week='202003', fields='prd,name,vol,amount')
```

数据示例

```python
exchange prd name        vol   vol_yoy       amount  amout_yoy    cumvol  \
0       SHFE  CU    铜  1078970.0    5.9664  2363.843445    -5.7003   6848849   
```